@@ -18,6 +18,9 @@ class Config(object):
   TIMEZONE_CACHE_PASSWORD = os.getenv('TIMEZONE_CACHE_PASSWORD')
   PC_MILER_HOURLY_LIMIT = 14000
   PC_MILER_MONTHLY_LIMIT = 300000
+  PARSED_CARRIER_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-parsed-carrier-test'
+  PARSED_CARRIER_SNS_SUBJECT = 'parsed-carrier'
+  PARSED_CARRIER_SNS_CLASS_NAME = 'com.cargochief.sdk.carrierhub.notifications.ParsedCarrierNotification'
 
 class LocalConfig(Config):
   """Configurations for running and debugging locally, with a separate local database."""
@@ -34,7 +37,7 @@ class DevelopmentConfig(Config):
 
 class ProductionConfig(Config):
   """Configurations for running in dev mode, with a remote database."""
-  
+  PARSED_CARRIER_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-parsed-carrier-prod'  
 
 config_options = {
     'local': LocalConfig,
