@@ -10,7 +10,7 @@ from ast import literal_eval
 
 def get_location(city, state, zipcode, logger):
   from_cache = False
-  pc_miler_can_be_called = None
+  pc_miler_can_be_called = False
   data = __get_location_from_cache(city, state, zipcode, logger)
 
   if data and data.get('postcode') and data.get('country'):
@@ -19,17 +19,17 @@ def get_location(city, state, zipcode, logger):
     data = None
 
   if not data:
-    logger.debug(f"geolocate.get_location - Couldn't find location: {city},{state} {zipcode} in cache. Calling PC Miler")
-    pc_miler_can_be_called = not pc_miler_limit_reached(logger)
+    logger.debug(f"geolocate.get_location - Couldn't find location: {city},{state} {zipcode} in cache.")
+    # pc_miler_can_be_called = not pc_miler_limit_reached(logger)
     
-    if pc_miler_can_be_called:
-      data = __get_pc_mile_location(city, state, zipcode, logger)
+    # if pc_miler_can_be_called:
+    #   data = __get_pc_mile_location(city, state, zipcode, logger)
 
-  if not data:
-    if not pc_miler_can_be_called:
-      logger.debug("geolocate.get_location - Couldn't call PC Miler as we reached the permissible limits. Calling google.")
-    else:
-      logger.debug(f"geolocate.get_location - PC Miler returned no result for ({city}, {state}, {zipcode}). Calling google")
+  # if not data:
+    # if not pc_miler_can_be_called:
+    #   logger.debug("geolocate.get_location - Couldn't call PC Miler as we reached the permissible limits. Calling google.")
+    # else:
+    #   logger.debug(f"geolocate.get_location - PC Miler returned no result for ({city}, {state}, {zipcode}). Calling google")
 
     data = __get_google_location(city, state, zipcode, logger)
 
@@ -47,25 +47,25 @@ def get_distance(origin_latitude, origin_longitude, destination_latitude, destin
     raise Exception("Calculating distance requires both origin and destination lat/lng")
 
   from_cache = False
-  pc_miler_can_be_called = None
+  pc_miler_can_be_called = False
   distance_cache_key = __get_distance_cache_key(origin_latitude, origin_longitude, destination_latitude, destination_longitude)
-
   distance = __get_distance_from_cache(distance_cache_key, logger)
+
   if distance:
     from_cache = True
 
   if not distance:
-    pc_miler_can_be_called = not pc_miler_limit_reached(logger)
+  #   pc_miler_can_be_called = not pc_miler_limit_reached(logger)
     
-    if pc_miler_can_be_called:
-      distance = __get_pc_miler_distance(origin_latitude, origin_longitude, destination_latitude, destination_longitude,
-                                     logger, distance_cache_key)
+  #   if pc_miler_can_be_called:
+  #     distance = __get_pc_miler_distance(origin_latitude, origin_longitude, destination_latitude, destination_longitude,
+  #                                    logger, distance_cache_key)
 
-  if not distance:
-    if not pc_miler_can_be_called:
-      logger.debug("geolocate.get_distance - Couldn't call PC Miler as we reached the permissible limits. Calling google.")
-    else:
-      logger.debug(f"geolocate.get_distance - PC Miler returned no result for {distance_cache_key}. Calling google")
+  # if not distance:
+  #   if not pc_miler_can_be_called:
+  #     logger.debug("geolocate.get_distance - Couldn't call PC Miler as we reached the permissible limits. Calling google.")
+  #   else:
+  #     logger.debug(f"geolocate.get_distance - PC Miler returned no result for {distance_cache_key}. Calling google")
       
     distance = __get_google_distance(origin_latitude, origin_longitude, destination_latitude, destination_longitude,
                                    logger, distance_cache_key)
